package com.acxiom.dsapi.auth;

import javax.ws.rs.core.Form;

public class ClientCredentialGrantRequest extends TokenGrantRequest {

    private String tokenUrl;
    private String apiKey;
    private String apiSecret;

    private static int TOKEN_EXPIRATION_BUFFER_TIME = 300;

    public ClientCredentialGrantRequest(String tokenUrl, String apiKey,
	    String apiSecret) {
	this(tokenUrl, apiKey, apiSecret, TOKEN_EXPIRATION_BUFFER_TIME);
    }

    public ClientCredentialGrantRequest(String tokenUrl, String apiKey,
	    String apiSecret, int tokenExpirationBufferSeconds) {
	super(tokenUrl, tokenExpirationBufferSeconds);

	this.tokenUrl = tokenUrl;
	this.apiKey = apiKey;
	this.apiSecret = apiSecret;
    }

    @Override
    public Form getRequestForm() {
	Form form = new Form();
	form.param("client_id", this.apiKey);
	form.param("client_secret", this.apiSecret);
	form.param("grant_type", "client_credentials");

	return form;
    }

    public String getTokenUrl() {
	return tokenUrl;
    }

    public void setTokenUrl(String tokenUrl) {
	this.tokenUrl = tokenUrl;
    }

    public String getApiKey() {
	return this.apiKey;
    }

    public void setApiKey(String apiKey) {
	this.apiKey = apiKey;
    }

    public String getApiSecret() {
	return this.apiSecret;
    }

    public void setApiSecret(String apiSecret) {
	this.apiSecret = apiSecret;
    }

    public static void main(String[] args) {
	if (args.length != 2) {
	    System.out
		    .println("Please provide apiKey and apiSecret as command line parameters");
	    System.exit(1);
	}
	String apiKey = args[0];
	String apiSecret = args[1];

	String tokenUrl = "https://login.myacxiom.com/api/v1/auth/oauth2/token";
	ClientCredentialGrantRequest tokenRequest = new ClientCredentialGrantRequest(
		tokenUrl, apiKey, apiSecret);

	Token token = tokenRequest.getToken();
	if (token != null) {
	    String accessToken = token.getAccessToken();
	    String expiresIn = token.getExpiresIn();
	    long tokenExpirationTimestamp = token.getExpirationTimeMillis();

	    System.out.println("accessToken: " + accessToken);
	    System.out.println("expires in: " + expiresIn);
	    System.out.println("expiration timestamp: "
		    + tokenExpirationTimestamp);
	}

    }
}
