package com.acxiom.dsapi.auth;

import javax.ws.rs.core.Form;

public class PasswordGrantRequest extends TokenGrantRequest {

    private String tokenUrl;
    private String apiKey;
    private String apiSecret;
    private String tenantSystemName;
    private String userName;
    private String password;

    private static int TOKEN_EXPIRATION_BUFFER_TIME = 300;

    public PasswordGrantRequest(String tokenUrl, String apiKey,
	    String apiSecret, String tenantSystemName, String userName,
	    String password) {
	this(tokenUrl, apiKey, apiSecret, tenantSystemName, userName, password,
		TOKEN_EXPIRATION_BUFFER_TIME);
    }

    public PasswordGrantRequest(String tokenUrl, String apiKey,
	    String apiSecret, String tenantSystemName, String userName,
	    String password, int tokenExpirationBufferSeconds) {
	super(tokenUrl, tokenExpirationBufferSeconds);

	this.tokenUrl = tokenUrl;
	this.apiKey = apiKey;
	this.apiSecret = apiSecret;
	this.tenantSystemName = tenantSystemName;
	this.userName = userName;
	this.password = password;
    }

    public String getTokenUrl() {
	return tokenUrl;
    }

    public void setTokenUrl(String tokenUrl) {
	this.tokenUrl = tokenUrl;
    }

    public String getApiKey() {
	return apiKey;
    }

    public void setApiKey(String apiKey) {
	this.apiKey = apiKey;
    }

    public String getApiSecret() {
	return apiSecret;
    }

    public void setApiSecret(String apiSecret) {
	this.apiSecret = apiSecret;
    }

    public String getTenantSystemName() {
	return tenantSystemName;
    }

    public void setTenantSystemName(String tenantSystemName) {
	this.tenantSystemName = tenantSystemName;
    }

    public String getUserName() {
	return userName;
    }

    public void setUserName(String userName) {
	this.userName = userName;
    }

    public String getPassword() {
	return password;
    }

    public void setPassword(String password) {
	this.password = password;
    }

    @Override
    public Form getRequestForm() {
	String tenantUser = "";

	if (this.tenantSystemName != null) {
	    tenantUser += this.tenantSystemName;
	    tenantUser += "\\";
	}
	tenantUser += this.userName;

	Form form = new Form();
	form.param("client_id", this.apiKey);
	form.param("client_secret", this.apiSecret);
	form.param("grant_type", "password");
	form.param("username", tenantUser);
	form.param("password", this.password);

	return form;
    }

    public static void main(String[] args) {
	if (args.length != 5) {
	    System.out
		    .println("Please provide apiKey, apiSecret, tenantSystemName, userName and password as command line parameters");
	    System.exit(1);
	}
	String apiKey = args[0];
	String apiSecret = args[1];
	String tenantSystemName = args[2];
	String userName = args[3];
	String password = args[4];

	String tokenUrl = "https://login.myacxiom.com/api/v1/auth/oauth2/token";
	PasswordGrantRequest tokenRequest = new PasswordGrantRequest(tokenUrl,
		apiKey, apiSecret, tenantSystemName, userName, password);

	Token token = tokenRequest.getToken();
	if (token != null) {
	    String accessToken = token.getAccessToken();
	    String expiresIn = token.getExpiresIn();
	    long tokenExpirationTimestamp = token.getExpirationTimeMillis();
	    String refreshToken = token.getRefreshToken();

	    System.out.println("accessToken: " + accessToken);
	    System.out.println("expires in: " + expiresIn);
	    System.out.println("expiration timestamp: "
		    + tokenExpirationTimestamp);
	    System.out.println("refreshToken: " + refreshToken);
	}

    }
}
