package com.acxiom.dsapi.auth;

import javax.ws.rs.core.Form;

public class RefreshTokenGrantRequest extends TokenGrantRequest {

    private String tokenUrl;
    private String apiKey;
    private String apiSecret;
    private String refreshToken;

    private static int TOKEN_EXPIRATION_BUFFER_TIME = 300;

    public RefreshTokenGrantRequest(String tokenUrl, String apiKey,
	    String apiSecret, String refreshToken) {
	this(tokenUrl, apiKey, apiSecret, refreshToken,
		TOKEN_EXPIRATION_BUFFER_TIME);
    }

    public RefreshTokenGrantRequest(String tokenUrl, String apiKey,
	    String apiSecret, String refreshToken,
	    int tokenExpirationBufferSeconds) {
	super(tokenUrl, tokenExpirationBufferSeconds);

	this.tokenUrl = tokenUrl;
	this.apiKey = apiKey;
	this.apiSecret = apiSecret;
	this.refreshToken = refreshToken;
    }

    @Override
    public Form getRequestForm() {
	Form form = new Form();
	form.param("client_id", this.apiKey);
	form.param("client_secret", this.apiSecret);
	form.param("refresh_token", this.refreshToken);
	form.param("grant_type", "refresh_token");

	return form;
    }

    public String getTokenUrl() {
	return tokenUrl;
    }

    public void setTokenUrl(String tokenUrl) {
	this.tokenUrl = tokenUrl;
    }

    public String getApiKey() {
	return apiKey;
    }

    public void setApiKey(String apiKey) {
	this.apiKey = apiKey;
    }

    public String getApiSecret() {
	return apiSecret;
    }

    public void setApiSecret(String apiSecret) {
	this.apiSecret = apiSecret;
    }

    public String getRefreshToken() {
	return refreshToken;
    }

    public void setRefreshToken(String refreshToken) {
	this.refreshToken = refreshToken;
    }

    public static void main(String[] args) {
	if (args.length != 3) {
	    System.out
		    .println("Please provide apiKey, apiSecret and refreshToken as command line parameters");
	    System.exit(1);
	}
	String apiKey = args[0];
	String apiSecret = args[1];
	String refreshToken = args[2];

	String tokenUrl = "https://login.myacxiom.com/api/v1/auth/oauth2/token";
	RefreshTokenGrantRequest tokenRequest = new RefreshTokenGrantRequest(
		tokenUrl, apiKey, apiSecret, refreshToken);

	Token token = tokenRequest.getToken();
	if (token != null) {
	    String accessToken = token.getAccessToken();
	    String expiresIn = token.getExpiresIn();
	    long tokenExpirationTimestamp = token.getExpirationTimeMillis();
	    String newRefreshToken = token.getRefreshToken();

	    System.out.println("accessToken: " + accessToken);
	    System.out.println("expires in: " + expiresIn);
	    System.out.println("expiration timestamp: "
		    + tokenExpirationTimestamp);
	    System.out.println("refreshToken: " + newRefreshToken);
	}
    }
}
