package com.acxiom.dsapi.auth;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;

@JsonIgnoreProperties(ignoreUnknown = true)
public class Token {

    @JsonProperty("access_token")
    private String accessToken;

    @JsonProperty("token_type")
    private String tokenType;

    @JsonProperty("expires_in")
    private String expiresIn;
    
    @JsonProperty("refresh_token")
    private String refreshToken;

    private long expirationTimeInMillis = -1;

    @JsonProperty("access_token")
    public String getAccessToken() {
	return this.accessToken;
    }

    @JsonProperty("access_token")
    public void setAccessToken(String accessToken) {
	this.accessToken = accessToken;
    }

    @JsonProperty("token_type")
    public String getTokenType() {
	return this.tokenType;
    }

    @JsonProperty("token_type")
    public void setTokenType(String tokenType) {
	this.tokenType = tokenType;
    }

    @JsonProperty("expires_in")
    public String getExpiresIn() {
	return this.expiresIn;
    }

    @JsonProperty("expires_in")
    public void setExpiresIn(String expiresIn) {
	this.expiresIn = expiresIn;

	long expiresInMillis = Long.parseLong(expiresIn) * 1000;

	this.expirationTimeInMillis = System.currentTimeMillis()
		+ expiresInMillis;
    }
    
    @JsonProperty("refresh_token")
    public String getRefreshToken() {
	return this.refreshToken;
    }

    @JsonProperty("refresh_token")
    public void setRefreshToken(String refreshToken) {
	this.refreshToken = refreshToken;
    }

    @JsonIgnore
    public long getExpirationTimeMillis() {
	return this.expirationTimeInMillis;
    }

    @JsonIgnore
    public String getAuthHeader() {
	return this.getTokenType() + " " + this.getAccessToken();
    }

    @JsonIgnore
    public boolean isValid() {
	boolean isValid = true;

	if (this.accessToken == null || "".equals(this.accessToken)) {
	    isValid = false;
	}

	if (this.tokenType == null || "".equals(this.tokenType)) {
	    isValid = false;
	}

	if (this.expiresIn == null || "".equals(this.expiresIn)) {
	    isValid = false;
	}

	if (this.expirationTimeInMillis > System.currentTimeMillis()) {
	    isValid = false;
	}

	return isValid;
    }
}
