package com.acxiom.dsapi.auth;

import javax.ws.rs.client.ClientBuilder;
import org.glassfish.jersey.client.ClientConfig;
import javax.ws.rs.client.Client;
import javax.ws.rs.client.Entity;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.Form;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import org.glassfish.jersey.jackson.JacksonFeature;

public abstract class TokenGrantRequest {
    
    private static int TOKEN_EXPIRATION_BUFFER_SECONDS = 300;
    
    private String tokenUrl = null;
    private int tokenExpirationBufferSeconds = TOKEN_EXPIRATION_BUFFER_SECONDS;
    
    public TokenGrantRequest(String tokenUrl) {
	this.tokenUrl = tokenUrl;
    }
    
    public TokenGrantRequest(String tokenUrl, int bufferTime) {
	this.tokenUrl = tokenUrl;
	this.tokenExpirationBufferSeconds = bufferTime;
    }

    public abstract Form getRequestForm();

    public Token getToken() {
	Response response = null;
	Token token = null;
	
        Client client = getClient();	
 
	if (client != null) {
	    WebTarget target = client.target(this.tokenUrl);
	    Form form = this.getRequestForm();

	    response = target.request(MediaType.APPLICATION_JSON_TYPE).post(
		    Entity.entity(form,
			    MediaType.APPLICATION_FORM_URLENCODED_TYPE),
		    Response.class);
	}

	if (response != null) {
	    int status = response.getStatus();
	    if (status == 200) {
		token = response.readEntity(Token.class);
	    } else {
		System.out.println("Call to toke service received status code " + status);
	    }
	} else {
	    System.out.println("Call to token service returned unexpected null response");
	}

	return token;
    }

    public int getTokenExpirationBufferSeconds() {
	return this.tokenExpirationBufferSeconds;
    }

    public void setTokenExpirationBufferSeconds(
	    int tokenExpirationBufferSeconds) {
	this.tokenExpirationBufferSeconds = tokenExpirationBufferSeconds;
    }
    
    private Client getClient() {
	ClientConfig clientConfig = new ClientConfig();
	ClientBuilder clientBuilder = ClientBuilder.newBuilder()
		.withConfig(clientConfig).register(JacksonFeature.class);
        Client client = clientBuilder.build();
        
        return client;
    }
}
